Index: trunk/MagicSoft/Mars/manalysis/MFiltercutsCalc.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MFiltercutsCalc.h	(revision 8075)
+++ trunk/MagicSoft/Mars/manalysis/MFiltercutsCalc.h	(revision 8091)
@@ -36,6 +36,6 @@
     TString GetHadronnessName() const { return fHadronnessName; }
 
-    void AddCut(const char *name, Double_t lo, Double_t up);
-    void AddCut(const char *name, Double_t val);
+    //void AddCut(const char *name, Double_t lo, Double_t up);
+    //void AddCut(const char *name, Double_t val);
     void AddCut(const char *cut);
     void AddCut(MFilter *f);

Index: trunk/MagicSoft/Mars/manalysis/MFiltercutsCalc.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MFiltercutsCalc.cc	(revision 8075)
+++ trunk/MagicSoft/Mars/manalysis/MFiltercutsCalc.cc	(revision 8091)
@@ -40,6 +40,5 @@
 #include "MLogManip.h"
 
-#include "MF.h"
-#include "MFDataChain.h"
+#include "MFDataPhrase.h"
 #include "MParList.h"
 #include "MFilterList.h"
@@ -98,14 +97,15 @@
 }
 
+/*
 // --------------------------------------------------------------------------
 //
 // There is MUCH space for speed improvement!
 // Add MF(lo<name && name<up) to the filter list (&&),
 // for more details see MF::MF(), too.
 //
 void MFiltercutsCalc::AddCut(const char *name, Double_t lo, Double_t up)
 {
-    AddToList(new MFDataChain(name, '>', lo));
-    AddToList(new MFDataChain(name, '<', up));
+    AddToList(new MFDataPhrase(Form("%s>%.15f", name, lo));
+    AddToList(new MFDataPhrase(name, '<', up));
 }
 
@@ -113,6 +113,6 @@
 //
 // There is MUCH space for speed improvement!
 // Add MF(fabs(name)<val) to the filter list (&&),
 // for more details see MF::MF(), too.
 //
 void MFiltercutsCalc::AddCut(const char *name, Double_t val)
@@ -120,4 +120,5 @@
     AddToList(new MFDataChain(Form("fabs(%s)", name), '<', val));
 }
+*/
 
 // --------------------------------------------------------------------------
@@ -125,9 +126,9 @@
 // There is MUCH space for speed improvement!
 // Add 'cut' as MF(cut) to the filter list (&&),
 // for more details see MF::MF(), too.
 //
 void MFiltercutsCalc::AddCut(const char *cut)
 {
-    AddToList(new MF(cut));
+    AddToList(new MFDataPhrase(cut));
 }
 
@@ -135,5 +136,5 @@
 //
 // There is MUCH space for speed improvement!
 // Add cut to filter list (&&), for more details see MF::MF(), too.
 //
 void MFiltercutsCalc::AddCut(MFilter *f)
@@ -98,14 +97,15 @@
 //
 // There is MUCH space for speed improvement!
-// Add MF(lo<name && name<up) to the filter list (&&),
-// for more details see MF::MF(), too.
+// Add MFDataPhrase(lo<name && name<up) to the filter list (&&),
+// for more details see MFDataPhrase::MFDataPhrase(), too.
 //
 void MFiltercutsCalc::AddCut(const char *name, Double_t lo, Double_t up)
@@ -113,6 +113,6 @@
 //
 // There is MUCH space for speed improvement!
-// Add MF(fabs(name)<val) to the filter list (&&),
-// for more details see MF::MF(), too.
+// Add MFDataPhrase(fabs(name)<val) to the filter list (&&),
+// for more details see MFDataPhrase::MFDataPhrase(), too.
 //
 void MFiltercutsCalc::AddCut(const char *name, Double_t val)
@@ -125,9 +126,9 @@
 // There is MUCH space for speed improvement!
 // Add 'cut' as MF(cut) to the filter list (&&),
-// for more details see MF::MF(), too.
+// for more details see MFDataPhrase::MFDataPhrase(), too.
 //
 void MFiltercutsCalc::AddCut(const char *cut)
@@ -135,5 +136,5 @@
 //
 // There is MUCH space for speed improvement!
-// Add cut to filter list (&&), for more details see MF::MF(), too.
+// Add cut to filter list (&&), for more details see MFDataPhrase::MFDataPhrase(), too.
 //
 void MFiltercutsCalc::AddCut(MFilter *f)